import { useDelete, useGet, usePost, usePut } from '~@/utils/request'

export async function getListApi(params) {
  return useGet('/v1/gatewayIp/getList', params)
}

export async function getList(params) {
  return useGet('/v1/gatewayIp/get', params)
}


export async function addApi(data) {
  return usePost('/v1/gatewayIp/add', data)
}

export async function updateApi(data) {
  return usePut('/v1/gatewayIp/edit', data)
}

export async function deleteApi(id) {
  return useDelete(`/v1/gatewayIp/del`, { id })
}

export async function deleteApiList(data) {
  return useDelete(`/v1/gatewayIp/delList`, data)
}